@@ -8,7 +8,7 @@
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of the
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -28,6 +28,7 @@
 #include "view.h"
 #include "window.h"
 #include <gcugtk/filechooser.h>
+#include <gcugtk/message.h>
 #include <gcu/loader.h>
 #include <glib/gi18n.h>
 #include <clocale>
@@ -82,7 +83,7 @@ void gsvApplication::OnQuit ()
 	}
 }
 
-bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, G_GNUC_UNUSED GtkWindow *window, Document *Doc)
+bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type, bool bSave, GtkWindow *window, Document *Doc)
 {
 	gsvDocument *pDoc = dynamic_cast <gsvDocument *> (Doc);
 	if(bSave) {
@@ -93,10 +94,9 @@ bool gsvApplication::FileProcess (const gchar* filename, const gchar* mime_type,
 			char *unescaped = g_uri_unescape_string (filename, NULL);
 			gchar * message = g_strdup_printf (_("File %s\nexists, overwrite?"), unescaped);
 			g_free (unescaped);
-			GtkDialog* Box = GTK_DIALOG (gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, message));
-			gtk_window_set_icon_name (GTK_WINDOW (Box), "gspectrum");
-			result = gtk_dialog_run (Box);
-			gtk_widget_destroy (GTK_WIDGET (Box));
+			gcugtk::Message *box = new gcugtk::Message (this, message, GTK_MESSAGE_QUESTION,
+			                                            GTK_BUTTONS_YES_NO, window);
+			result = box->Run ();
 			g_free (message);
 		}
 		if (result == GTK_RESPONSE_YES) {
